### To play around with code in the other files ###

# if __name__ == '__main__':
import toolkit_lennart.plot as plot
import pandas as pd

df = pd.DataFrame([1,1,2,3,5,8,13,21,34,55], list(range(10)))
fig = plot.df_col_plot(df, df.index, 0)
#fig.show()

plot.help()




from distutils.core import setup

setup(name='Distutils',
      version='0.0.2',
      description='Toolkit Lennart',
      author='Lennart Rooden',
      author_email='lennart.rs@gmail.com',
      url='https://pypi.org/project/toolkit-lennart/0.0.1/',
      packages=['toolkit_lennart'],
     )


import pandas as pd
import numpy as np
import plotly.express as px
import os

def help():
    DIR = os.path.dirname(os.path.abspath(__file__))
    f = open(DIR+'/plot_help.txt', mode = 'r')
    print(f.read())
    return

# Desired functions:
# DF to line/scatter
# DF to multiple line/scatter in 1 plot
# DF to multiple line/scatter plots
# ...

def df_col_plot(df = None, x_name = None, y_name = None, help = False):
    if help:
        print('Plots two df columns. Arguments: df, x_name (df.index for index), y_name')
        return


    fig = px.scatter(df, x_name, y_name)
    return fig
